# Generated by Django 4.2.11 on 2024-05-29 12:54

from django.conf import settings
from django.db import migrations, models

import opcalendar.models


class Migration(migrations.Migration):
    dependencies = [
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
        ("opcalendar", "0026_alter_event_repeat_event"),
    ]

    operations = [
        migrations.AddField(
            model_name="eventmember",
            name="comment",
            field=models.CharField(
                blank=True, help_text="Optional comment about the event", max_length=100
            ),
        ),
        migrations.AddField(
            model_name="eventmember",
            name="status",
            field=models.CharField(
                choices=[("A", "Attending"), ("M", "Maybe"), ("D", "Declined")],
                default="A",
                max_length=1,
            ),
        ),
        migrations.CreateModel(
            name="UserSettings",
            fields=[
                (
                    "id",
                    models.AutoField(
                        auto_created=True,
                        primary_key=True,
                        serialize=False,
                        verbose_name="ID",
                    ),
                ),
                (
                    "disable_discord_notifications",
                    models.BooleanField(
                        default=True, verbose_name="Discord Notifications"
                    ),
                ),
                (
                    "use_local_times",
                    models.BooleanField(default=True, verbose_name="Use Local Times"),
                ),
                (
                    "user",
                    models.ForeignKey(
                        blank=True,
                        default=None,
                        null=True,
                        on_delete=models.SET(opcalendar.models.get_sentinel_user),
                        related_name="+",
                        to=settings.AUTH_USER_MODEL,
                    ),
                ),
            ],
            options={
                "verbose_name": "User Settings",
                "verbose_name_plural": "User Settings",
                "default_permissions": (),
            },
        ),
    ]
