{% load static %}
{% load i18n %}
{% load navactive %}

<li class="nav-item">
    {% if perms.opcalendar.create_event %}
        <a class="nav-link py-0" href="{% url 'opcalendar:event_new' %}">
            <span class="btn btn-info">
                <i class="fas fa-calendar-plus"></i> {% trans "New Event" %}
            </span>
        </a>
    {% endif %}
</li>

<li class="nav-item">
    {% if perms.opcalendar.add_ingame_calendar_owner %}
        <a class="nav-link py-0" href="{% url 'opcalendar:add_ingame_calendar' %}">
            <span class="btn btn-success">
                <i class="fas fa-sync"></i> {% trans "Add Ingame Calendar Feed" %}
            </span>
        </a>
    {% endif %}
</li>

<li class="nav-item">
    <a class="nav-link py-0" href="{% url 'opcalendar:user_settings' %}">
        <span class="btn btn-warning">
            <i class="fas fa-cog"></i> {% trans "My Settings" %}
        </span>
    </a>
</li>
