# Generated by Django 3.1.2 on 2020-11-04 11:27

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("opcalendar", "0004_event_host"),
    ]

    operations = [
        migrations.AlterField(
            model_name="event",
            name="host",
            field=models.ForeignKey(
                default=1,
                null=True,
                on_delete=django.db.models.deletion.CASCADE,
                to="opcalendar.eventhost",
            ),
        ),
    ]
