{% extends 'opcalendar/base.html' %}
{% load i18n %}

{% block page_title %}{% trans "User Settings" %}{% endblock page_title %}

{% block content %}
<div class="container mt-4">
    <div class="card">
        <div class="card-header">
            <h4 class="card-title">{% trans "User Settings" %}</h4>
        </div>
        <div class="card-body">
            {% if messages %}
                <div class="mb-3">
                    {% for message in messages %}
                        <div class="alert {% if message.tags %}alert-{{ message.tags }}{% else %}alert-info{% endif %}" role="alert">
                            {{ message }}
                        </div>
                    {% endfor %}
                </div>
            {% endif %}
            <form method="post">
                {% csrf_token %}
                {{ form.as_p }}
                <button type="submit" class="btn btn-primary">{% trans "Save Settings" %}</button>
            </form>
        </div>
    </div>
</div>
{% endblock content %}
