from esi.openapi_clients import ESIClientProvider

from . import __version__

esi = ESIClientProvider(
    compatibility_date="2025-08-26",  # <-- replace with the same value eveuniverse/providers.py uses
    ua_appname="aa-opcalendar",
    ua_version=__version__,
    operations=[
        "GetCharactersCharacterIdCalendar",
        "GetCharactersCharacterIdCalendarEventId",
        "PostUniverseIds",
        "GetAlliancesAllianceId",
        "GetCorporationsCorporationId",
    ],
)
