{% load i18n %}

<ul class="nav nav-pills card-header-pills w-100 d-flex align-items-center">
    <li class="nav-item">
        <a class="btn btn-info mr-2" href="{% url 'opcalendar:calendar' %}?{{ prev_month }}">
            <i class="fas fa-backward"></i>{% trans "Previous Month" %}
        </a>
    </li>
    <li class="nav-item flex-grow-1 text-center">
        <span class="navbar-text"><h4>{% trans "Operation Calendar" %}</h4></span>
    </li>
    <li class="nav-item ms-auto">
        <a class="btn btn-info" href="{% url 'opcalendar:calendar' %}?{{ next_month }}">
            {% trans "Next Month" %} <i class="fas fa-forward"></i>
        </a>
    </li>
</ul>
